;; Emacs!!!

(package-initialize)

(when (version<= emacs-version "24")
  (error "This is made form Emacs >=24"))

(defconst emacs-start-time (current-time))
(add-to-list 'load-path (expand-file-name "~/.emacs.d/lisp/" user-emacs-directory))

;;; Raise garbage collection threshold after init
(add-hook 'after-init-hook
	  (lambda () (setq gc-cons-threshold local/gc-cons-threshold)))

;;; Custom variables
(setq custom-file (expand-file-name "custom.el" user-emacs-directory))
;;; Custom settings
(setq settings-file (expand-file-name "settings.el" user-emacs-directory))

;;; Loads settings file
(when (file-exists-p custom-file)
  (load settings-file))
;;;------------------------------
;;; Features
;;;------------------------------
(require 'init-security)
(require 'init-elpa)
;; theme
(require 'init-theme)
;; Utils
(require 'init-utils)
;; GUI
(require 'init-nlinum)
(require 'init-gui)
(require 'init-editing-utils)
(require 'init-modeline)
;; Tools
(require 'init-flycheck)
;; Languages
(require 'init-markdown)
(require 'init-python)
(require 'init-pkgbuild)
(require 'init-php)
(require 'init-less)
(require 'init-sass)
(require 'init-scss)
;; Plus
(require 'init-rainbow)

;;; Loads custom file
(when (file-exists-p custom-file)
  (load custom-file))

(when window-system
  (let ((elapsed (float-time (time-subtract (current-time)
                                            emacs-start-time))))
    (message "[STARTUP] Loading %s ... done (%.3fs)" load-file-name elapsed)))

(provide 'init)
